<?php

	/**
	 * Brazilian Portuguese language file for phpPgAdmin.
	 * @maintainer ngelo Marcos Rigo (angelo_rigo@yahoo.com.br)
	 *
	 * $Id: portuguese-br.php,v 1.8 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Portugus-Brasileiro';
	$lang['appcharset'] = 'ISO-8859-1';
	$lang['applocale'] = 'pt_BR';
  	$lang['appdbencoding'] = 'LATIN1';
	$lang['applangdir'] = 'ltr';
  
	// Basic strings
	$lang['strintro'] = 'Bem-vindo ao phpPgAdmin.';	
$lang['strppahome'] = 'Pgina inicial phpPgAdmin ';
$lang['strpgsqlhome'] = 'Pgina inicial PostgreSQL ';
$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
$lang['strreportbug'] = 'Reportar um Bug';
$lang['strviewfaq'] = 'Visualizar FAQ';
$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	$lang['strlogin'] = 'Identificao';					
	$lang['strloginfailed'] = 'Falha na identificao';		
	$lang['strserver'] = 'Servidor';					
	$lang['strlogout'] = 'Deslogar';					
	$lang['strowner'] = 'Propietrio';					
	$lang['straction'] = 'Ao';					
	$lang['stractions'] = 'Aes';				
	$lang['strname'] = 'Nome';						
	$lang['strdefinition'] = 'Definio';		
	$lang['stroperators'] = 'Operadores';			
	$lang['straggregates'] = 'Agregados';			
	$lang['strproperties'] = 'Propriedades';			
	$lang['strbrowse'] = 'Navegar';					
	$lang['strdrop'] = 'Deletar';						
	$lang['strdropped'] = 'Deletado';				
	$lang['strnull'] = 'Nulo';						
	$lang['strnotnull'] = 'No Nulo';				
	$lang['strprev'] = 'Anterior';						
	$lang['strnext'] = 'Prximo';							
	$lang['strfailed'] = 'Falha';					
	$lang['strcreate'] = 'Criar';					
	$lang['strcreated'] = 'Criado';				
	$lang['strcomment'] = 'Comentrio';				
	$lang['strlength'] = 'Extenso';					
	$lang['strdefault'] = 'Padro';				
	$lang['stralter'] = 'Alterar';					
	$lang['strok'] = 'OK';							
	$lang['strcancel'] = 'Cancelar';					
	$lang['strsave'] = 'Salvar';						
	$lang['strreset'] = 'Reiniciar';					
	$lang['strinsert'] = 'Inserir';					
	$lang['strselect'] = 'Selecionar';					
	$lang['strdelete'] = 'Deletar';					
	$lang['strupdate'] = 'Atualizar';				
	$lang['strreferences'] = 'Referncias';			
	$lang['stryes'] = 'Sim';						
	$lang['strno'] = 'No';							
	$lang['stredit'] = 'Editar';					
	$lang['strcolumns'] = 'Colunas';				
	$lang['strrows'] = 'Linha(s)';					
	$lang['strrowsaff'] = 'Linha(s) afetadas.';		
	$lang['strexample'] = 'eg.';					
	$lang['strback'] = 'Voltar';						
	$lang['strqueryresults'] = 'Resultados da pesquisa';		
	$lang['strshow'] = 'Exibir';						
	$lang['strempty'] = 'Vazio';					
	$lang['strlanguage'] = 'Linguagem';				
	$lang['strencoding'] = 'Codificao';				
	$lang['strvalue'] = 'Valor';					
	$lang['strunique'] = 'nico';					
	$lang['strprimary'] = 'Primrio';				
	$lang['strexport'] = 'Exportar';				
	$lang['strsql'] = 'SQL';						
	$lang['strgo'] = 'Ir';							
$lang['strimport'] = 'Importar';
	$lang['stradmin'] = 'Administrador';					
	$lang['strvacuum'] = 'Vcuo';					
	$lang['stranalyze'] = 'Analiza';				
	$lang['strclusterindex'] = 'Cluster';				
	$lang['strreindex'] = 'Reordenar';				
	$lang['strrun'] = 'Rodar';						
	$lang['stradd'] = 'Adicionar';						
	$lang['strevent'] = 'Evento';					
	$lang['strwhere'] = 'Onde';					
	$lang['strinstead'] = 'Fazer ao invs';				
	$lang['strwhen'] = 'Quando';						
	$lang['strformat'] = 'Formato';					

	// Error handling
$lang['strdata'] = 'Data';
$lang['strconfirm'] = 'Confirmar';
$lang['strexpression'] = 'Expresso';
$lang['strellipsis'] = '...';
$lang['strexpand'] = 'Expandir';
$lang['strcollapse'] = 'Diminuir';
	$lang['strbadconfig'] = 'Seu config.inc.php est desatualizado. Voc deve ger-lo novamente a partir do novo config.inc.php-dist.';
	$lang['strnotloaded'] = 'Voc no compilou suporte  banco de dados apropriado em sua instalao do PHP.';
	$lang['strbadschema'] = 'Esquema invlido especificado.';
	$lang['strbadencoding'] = 'Falha ao definir codificao do cliente no banco de dados.';
	$lang['strsqlerror'] = 'Erro de SQL:';
	$lang['strinstatement'] = 'Indicao de entrada :';
	$lang['strinvalidparam'] = 'Parmetros de script invlidos.';
	$lang['strnodata'] = 'No foram encontradas linhas.';

	// Tables
	$lang['strtable'] = 'Tabela';
	$lang['strtables'] = 'Tabelas';
	$lang['strshowalltables'] = 'Exibir todas as tabelas';
	$lang['strnotables'] = 'Tabelas no encontradas .';
	$lang['strnotable'] = 'Tabela no encontradas.';
	$lang['strcreatetable'] = 'Criar tabela';
	$lang['strtablename'] = 'Nome da tabela ';
	$lang['strtableneedsname'] = 'Voc deve dar um nome  sua tabela.';
	$lang['strtableneedsfield'] = 'Voc deve especificar pelo menos um campo.';
	$lang['strtableneedscols'] = 'Tabelas requerem um nmero vlido de colunas.';
	$lang['strtablecreated'] = 'Tabela criada.';
	$lang['strtablecreatedbad'] = 'Falha na criao de tabela.';
	$lang['strconfdroptable'] = 'Tem certeza que quer deletar a tabela "%s"?';
	$lang['strtabledropped'] = 'Tabela deletada.';
	$lang['strtabledroppedbad'] = 'Falha na deleo de tabela.';
	$lang['strconfemptytable'] = 'Tem certeza que quer esvaziar a tabela "%s"?';
	$lang['strtableemptied'] = 'Tabela esvaziada.';
	$lang['strtableemptiedbad'] = 'Falha no esvaziamento de tabela.';
	$lang['strinsertrow'] = 'Inserir linha';
	$lang['strrowinserted'] = 'Linha inserida.';
	$lang['strrowinsertedbad'] = 'Falha ao inserir linha.';
	$lang['streditrow'] = 'Editar linha';
	$lang['strrowupdated'] = 'Linha modificada.';
	$lang['strrowupdatedbad'] = 'Falha na modificao de linha.';
	$lang['strdeleterow'] = 'Deletar linha';
	$lang['strconfdeleterow'] = 'Tem certeza que quer deletar esta linha?';
	$lang['strrowdeleted'] = 'Linha deletada.';
	$lang['strrowdeletedbad'] = 'Falha na deleo de linha .';
	$lang['strsaveandrepeat'] = 'Salve & Repita';
	$lang['strfield'] = 'Campo';
	$lang['strfields'] = 'Campos';
	$lang['strnumfields'] = 'Nmero de campos';
	$lang['strfieldneedsname'] = 'Voc deve nomear seu campo';
	$lang['strselectneedscol'] = 'Voc deve exibir ao menos uma coluna';
	$lang['straltercolumn'] = 'Alterar coluna';
	$lang['strcolumnaltered'] = 'Coluna altereda.';
	$lang['strcolumnalteredbad'] = 'Falha na alterao de coluna.';
	$lang['strconfdropcolumn'] = 'Tem certeza que quer deletar a coluna "%s" da tabela "%s"?';
	$lang['strcolumndropped'] = 'Coluna deletada.';
	$lang['strcolumndroppedbad'] = 'Deleo de coluna falhou.';
	$lang['straddcolumn'] = 'Adicione coluna';
	$lang['strcolumnadded'] = 'Coluna adicionada.';
	$lang['strcolumnaddedbad'] = 'Adio de coluna falhou.';
	$lang['strschemaanddata'] = 'Esquema & Dados';
	$lang['strschemaonly'] = 'Esquema apenas';
	$lang['strdataonly'] = 'Dados apenas';

	// Users
$lang['strcascade'] = 'CASCATA';
	$lang['struseradmin'] = 'Administrao de usurio ';
	$lang['struser'] = 'Usurio';
	$lang['strusers'] = 'Usurios';
	$lang['strusername'] = 'Nome de usurio';
	$lang['strpassword'] = 'Senha';
	$lang['strsuper'] = 'Superusurio?';
	$lang['strcreatedb'] = 'Criar DB?';
	$lang['strexpires'] = 'Expira';
	$lang['strnousers'] = 'Usurios no encontrados.';
    $lang['struserupdated'] = 'Usurio alterado.';
	$lang['struserupdatedbad'] = 'Alterao de usurio falhou.';
	$lang['strshowallusers'] = 'Exibir todos os usurios';
	$lang['strcreateuser'] = 'Criar Usurio';
	$lang['strusercreated'] = 'Usurio criado.';
	$lang['strusercreatedbad'] = 'Falhou ao criar usurio.';
	$lang['strconfdropuser'] = 'Tem certeza que quer deletar o usurio "%s"?';
	$lang['struserdropped'] = 'Usurio deletado.';
	$lang['struserdroppedbad'] = 'Falha ao deletar usurio.';
		
	// Groups
$lang['straccount'] = 'Conta';
$lang['strchangepassword'] = 'Alterar senha';
$lang['strpasswordchanged'] = 'Senha alterada.';
$lang['strpasswordchangedbad'] = 'Falha ao alterar senha.';
$lang['strpasswordshort'] = 'Senha muito curta.';
$lang['strpasswordconfirm'] = 'Senha no confere com a confirmao.';
	$lang['strgroupadmin'] = 'Administrao de Grupo';
	$lang['strgroup'] = 'Grupo';
	$lang['strgroups'] = 'Grupos';
	$lang['strnogroups'] = 'Grupos no encotrados.';
	$lang['strshowallgroups'] = 'Exibir todos os grupos';
	$lang['strgroupneedsname'] = 'Voc deve dar um nome ao seu grupo.';
	$lang['strgroupcreated'] = 'Grupo criado.';
	$lang['strgroupcreatedbad'] = 'Falha na criao de grupo.';	
	$lang['strconfdropgroup'] = 'Tem certeza que quer deletar o grupo "%s"?';
	$lang['strgroupdropped'] = 'Grupo deletado.';
	$lang['strgroupdroppedbad'] = 'Falha ao deletar grupo.';
	$lang['strmembers'] = 'Membros';

	// Privilges
	$lang['strprivilege'] = 'Privilgio';
	$lang['strprivileges'] = 'Privilgios';
	$lang['strnoprivileges'] = 'Este objeto tem privilgios padres de proprietrio.';
	$lang['strgrant'] = 'Concede';
	$lang['strrevoke'] = 'Revoga';
	$lang['strgranted'] = 'Privilgios concedidos.';
	$lang['strgrantfailed'] = 'Falha ao conceder privilgios.';
$lang['strgrantbad'] = 'Voc deve especificar ao menos um usurio ou grupo e ao menos um privilgio.';
$lang['stralterprivs'] = 'Alterar privilgios';

	// Databases
	$lang['strdatabase'] = 'Banco de dados';
	$lang['strdatabases'] = 'Banco de dados';
	$lang['strshowalldatabases'] = 'Exibir todos os banco de dados';
	$lang['strnodatabase'] = 'Banco de dado no encontrado.';
	$lang['strnodatabases'] = 'Bancos de dados no encontrados.';
	$lang['strcreatedatabase'] = 'Criar banco de dados';
	$lang['strdatabasename'] = 'Nome do banco de dados';
	$lang['strdatabaseneedsname'] = 'Voc deve dar um nome ao seu banco de dados.';
	$lang['strdatabasecreated'] = 'Banco de dados criado.';
	$lang['strdatabasecreatedbad'] = 'Falhou na criao de Banco de dados.';	
	$lang['strconfdropdatabase'] = 'Tem certeza que quer deletar o banco de dados"%s"?';
	$lang['strdatabasedropped'] = 'Banco de dados deletado.';
	$lang['strdatabasedroppedbad'] = 'Falha na deleo de banco de dados.';
	$lang['strentersql'] = 'Digite a clusula SQL a ser executada abaixo :';
	$lang['strsqlexecuted'] = 'SQL executado.';
	$lang['strvacuumgood'] = 'Vcuo completo.';
	$lang['strvacuumbad'] = 'Falha ao executar vcuo.';
	$lang['stranalyzegood'] = 'Anlize completa.';
	$lang['stranalyzebad'] = 'Falha ao executar anlize.';

	// Views
	$lang['strview'] = 'Visualizao';
	$lang['strviews'] = 'Visualizaes';
	$lang['strshowallviews'] = 'Exibir todas as visualizaes';
	$lang['strnoview'] = 'Visualizao no encontrada.';
	$lang['strnoviews'] = 'Visualizaes no encontradas.';
	$lang['strcreateview'] = 'Criar visualizao';
	$lang['strviewname'] = 'Nome da visualizao';
	$lang['strviewneedsname'] = 'Voc deve dar um nome a sua visualizao.';
	$lang['strviewneedsdef'] = 'Voc deve dar uma definio para sua visualizao.';
	$lang['strviewcreated'] = 'Visualizao criada.';
	$lang['strviewcreatedbad'] = 'Falha na criao de visualizao.';
	$lang['strconfdropview'] = 'Tem certeza que quer deletar a visualizao "%s"?';
	$lang['strviewdropped'] = 'Visualizao deletada.';
	$lang['strviewdroppedbad'] = 'Falha na deleo de visualizao.';
	$lang['strviewupdated'] = 'Visualizao alterada.';
	$lang['strviewupdatedbad'] = 'Falha ao alterar visualizao.';

	// Sequences
	$lang['strsequence'] = 'Sequncia';
	$lang['strsequences'] = 'Sequncias';
	$lang['strshowallsequences'] = 'Exibir todas as sequncias';
	$lang['strnosequence'] = 'Sequncia no encontrada.';
	$lang['strnosequences'] = 'Sequncias no encontradas.';
	$lang['strcreatesequence'] = 'Criar sequncia';
	$lang['strlastvalue'] = 'ltimo valor';
	$lang['strincrementby'] = 'Incrementar por';	
	$lang['strstartvalue'] = 'Valor inicial';
	$lang['strmaxvalue'] = 'Valor mximo';
	$lang['strminvalue'] = 'Valor mnimo';
	$lang['strcachevalue'] = 'Valor de cache';
	$lang['strlogcount'] = 'Contador do log';
	$lang['striscycled'] = 'Foi dado um ciclo ?';
	$lang['strsequenceneedsname'] = 'Voc deve dar um nome a sua sequncia.';
	$lang['strsequencecreated'] = 'Sequncia criada.';
	$lang['strsequencecreatedbad'] = 'Falha na criao de sequncia.'; 
	$lang['strconfdropsequence'] = 'Tem certeza que quer deletar a sequncia "%s"?';
	$lang['strsequencedropped'] = 'Sequncia deletada.';
	$lang['strsequencedroppedbad'] = 'Falha na deleo de sequncia.';

	// Indexes
	$lang['strindexes'] = 'ndices';
	$lang['strindexname'] = 'Nome do ndice';
	$lang['strshowallindexes'] = 'Exibir todos os ndices';
	$lang['strnoindex'] = 'ndice no encontrado.';
	$lang['strnoindexes'] = 'ndices no encontrados.';
	$lang['strcreateindex'] = 'Criar ndice';
	$lang['strindexname'] = 'Nome do ndice';
	$lang['strtabname'] = 'Nome da tabela';
	$lang['strcolumnname'] = 'Nome da coluna';
	$lang['strindexneedsname'] = 'Voc deve dar um nome ao seu ndice';
	$lang['strindexneedscols'] = 'ndices requerem um nmero vlido de colunas.';
	$lang['strindexcreated'] = 'ndice criado';
	$lang['strindexcreatedbad'] = 'Falha na criao de ndice.';
	$lang['strconfdropindex'] = 'Tem certeza que quer deletar o ndice "%s"?';
	$lang['strindexdropped'] = 'ndice deletado.';
	$lang['strindexdroppedbad'] = 'Falha na deleo de ndice.';
	$lang['strkeyname'] = 'Nome da chave';
	$lang['struniquekey'] = 'Chave nica';
	$lang['strprimarykey'] = 'Chave primria';
 	$lang['strindextype'] = 'Tipo de ndice';
	$lang['strindexname'] = 'Nome do ndice';
	$lang['strtablecolumnlist'] = 'Colunas na tabela';
	$lang['strindexcolumnlist'] = 'Colunas no ndice';

	// Rules
	$lang['strrules'] = 'Regras';
	$lang['strrule'] = 'Regra';
	$lang['strshowallrules'] = 'Exibir todas as regras';
	$lang['strnorule'] = 'Regra no encontrada.';
	$lang['strnorules'] = 'Regras no encontradas.';
	$lang['strcreaterule'] = 'Criar regra';
	$lang['strrulename'] = 'Nome da regra';
	$lang['strruleneedsname'] = 'Voc deve especificar um nome para sua regra.';
	$lang['strrulecreated'] = 'Regra criada.';
	$lang['strrulecreatedbad'] = 'Falha na criao de regra.';
	$lang['strconfdroprule'] = 'Tem certeza que quer deletar a regra "%s" on "%s"?';
	$lang['strruledropped'] = 'Regra deletada.';
	$lang['strruledroppedbad'] = 'Falha na deleo de regra.';

	// Constraints
	$lang['strconstraints'] = 'Restrio';
	$lang['strshowallconstraints'] = 'Exibir todos as restries';
	$lang['strnoconstraints'] = 'Restries no encontradas.';
	$lang['strcreateconstraint'] = 'Criar restrio';
	$lang['strconstraintcreated'] = 'Restrio criada.';
	$lang['strconstraintcreatedbad'] = 'Falha na criao de restrio.';
	$lang['strconfdropconstraint'] = 'Tem certeza que quer deletar a restrio "%s" on "%s"?';
	$lang['strconstraintdropped'] = 'Restrio deletada.';
	$lang['strconstraintdroppedbad'] = 'Falha na deleo de restrio.';
	$lang['straddcheck'] = 'Adicona checagem';
	$lang['strcheckneedsdefinition'] = 'Checagem de regras necessita de uma definio.';
	$lang['strcheckadded'] = 'Checagem de restrio adicionada.';
	$lang['strcheckaddedbad'] = 'Falha ao adicionar checagem de restrio.';
	$lang['straddpk'] = 'Adicionar chave primria';
	$lang['strpkneedscols'] = 'Chave primria requer pelo menos uma coluna.';
	$lang['strpkadded'] = 'Chave primria adicionada.';
	$lang['strpkaddedbad'] = 'Falha ao adicinoar chave primria.';
	$lang['stradduniq'] = 'Adiciona chave nica';										
	$lang['struniqneedscols'] = 'Chave nica requer ao menos uma coluna.';					
	$lang['struniqadded'] = 'Chave nica adicionada.';										
	$lang['struniqaddedbad'] = 'Falha ao adicionar chave nica.';								
	$lang['straddfk'] = 'Adicionar chave estrangeira';												
	$lang['strfkneedscols'] = 'Chave estrangeira requer ao menos uma coluna.';				
	$lang['strfkneedstarget'] = 'Chave estrangeira requer uma tabela de referncia.';				
	$lang['strfkadded'] = 'Chave estrangeira adicionada.';										
	$lang['strfkaddedbad'] = 'Falha ao adicionar chave estrangeira.';							
	$lang['strfktarget'] = 'Tabela alvo';											
	$lang['strfkcolumnlist'] = 'Colunas em chaves';									
	$lang['strondelete'] = 'DELETE ATIVO';												
	$lang['stronupdate'] = 'ALTERAR ATIVO';	

	// Functions
	$lang['strfunction'] = 'Funo';
	$lang['strfunctions'] = 'Funes';
	$lang['strshowallfunctions'] = 'Exibir todas as funes';
	$lang['strnofunction'] = 'Funo no encontrada.';
	$lang['strnofunctions'] = 'Funes no encontradas.';
	$lang['strcreatefunction'] = 'Criar funes';
	$lang['strfunctionname'] = 'Nome da funo';
	$lang['strreturns'] = 'Retorno';
	$lang['strarguments'] = 'Argumentos';
	$lang['strproglanguage'] = 'Linguagem';				
	$lang['strfunctionneedsname'] = 'Voc deve dar um nome  sua funo.';
	$lang['strfunctionneedsdef'] = 'Voc deve dar uma definio  sua funo.';
	$lang['strfunctioncreated'] = 'Funo criada.';
	$lang['strfunctioncreatedbad'] = 'Falha na criao de funo.';
	$lang['strconfdropfunction'] = 'Tem certeza que quer deletar a funo "%s"?';
	$lang['strfunctiondropped'] = 'Funo deletada.';
	$lang['strfunctiondroppedbad'] = 'Falha na deleo de funo.';
	$lang['strfunctionupdated'] = 'Funo modificada.';
	$lang['strfunctionupdatedbad'] = 'Falha na modificao de funo.';

	// Triggers
	$lang['strtrigger'] = 'Gatilho';	
	$lang['strtriggers'] = 'Gatilhos';	
	$lang['strshowalltriggers'] = 'Exibir todos os gatilhos';	
	$lang['strnotrigger'] = 'No foi encontrado gatilho.';		
	$lang['strnotriggers'] = 'No foram encontrados gatilhos.';		
	$lang['strcreatetrigger'] = 'Criar Gatilhos';		
	$lang['strtriggerneedsname'] = 'Voc deve especificar um nome para seu gatilho.';	
	$lang['strtriggerneedsfunc'] = 'Voc deve especificar uma funo para seu gatilho.';
	$lang['strtriggercreated'] = 'Gatilho criado.';
	$lang['strtriggercreatedbad'] = 'Falha na criao de gatilho.';			
	$lang['strconfdroptrigger'] = 'Tem certeza que quer deletar o gatilho "%s" em "%s"?';	 
	$lang['strtriggerdropped'] = 'Gatilho deletado.'; 
	$lang['strtriggerdroppedbad'] = 'Falha na deleo de gatilho.';	

	// Types
	$lang['strtype'] = 'Tipo';		
	$lang['strtypes'] = 'Tipos';	
	$lang['strshowalltypes'] = 'Exibir todos os tipos';	
	$lang['strnotype'] = 'Tipo no encontrado.';			
	$lang['strnotypes'] = 'Tipos no encontrados.';		
	$lang['strcreatetype'] = 'Criar tipo';			
	$lang['strtypename'] = 'Nome do tipo';				
	$lang['strinputfn'] = 'Funo de entrada';			
	$lang['stroutputfn'] = 'Funo de sada';		
	$lang['strpassbyval'] = 'Passado por valor?';		
	$lang['stralignment'] = 'Alinhamento';			
	$lang['strelement'] = 'Elemento';				
	$lang['strdelimiter'] = 'Delimitador';			
	$lang['strstorage'] = 'Armazenamento';				
	$lang['strtypeneedsname'] = 'Voc deve dar um nome ao seu tipo.';		
	$lang['strtypeneedslen'] = 'Voce deve dar uma extenso ao seu tipo.';		
	$lang['strtypecreated'] = 'Tipo criado';								
	$lang['strtypecreatedbad'] = 'Criao de tipo falhou.';					
	$lang['strconfdroptype'] = 'Tem certeza que que deletar o tipo "%s"?';	
	$lang['strtypedropped'] = 'Tipo deletado.';									
	$lang['strtypedroppedbad'] = 'Deleo de tipo falhou.';							

	// Schemas
	$lang['strschema'] = 'Esquema';	 
	$lang['strschemas'] = 'Esquemas';		
	$lang['strshowallschemas'] = 'Exibir todos os esquemas';	
	$lang['strnoschema'] = 'Esquema no encontado.';		
	$lang['strnoschemas'] = 'No foram encontrados esquemas.';	
	$lang['strcreateschema'] = 'Criar esquema';		
	$lang['strschemaname'] = 'Nome do esquema';		
	$lang['strschemaneedsname'] = 'Voc deve dar um nome ao seu esquema.';		
	$lang['strschemacreated'] = 'Esquema criado';		
	$lang['strschemacreatedbad'] = 'Falha na criao de esquemas.';		
	$lang['strconfdropschema'] = 'Tem certeza que quer deletar o esquema "%s"?';	
	$lang['strschemadropped'] = 'Esquema deletado.';		
	$lang['strschemadroppedbad'] = 'Falha na deleo de esquema.';		

	// Reports
	$lang['strreport'] = 'Reporte';			
	$lang['strreports'] = 'Reportes';			
	$lang['strshowallreports'] = 'Exibir todos os reportes';		
	$lang['strnoreports'] = 'Reporte no encontrado.';		
	$lang['strcreatereport'] = 'Criar reporte';		
	$lang['strreportdropped'] = 'Reporte deletado.';		
	$lang['strreportdroppedbad'] = 'Falha ao deletar o reporte.';		
	$lang['strconfdropreport'] = 'Tem certeza que voc quer deletar seu reporte "%s"?';		
	$lang['strreportneedsname'] = 'Voc deve dar um nome ao seu reporte.';	
	$lang['strreportneedsdef'] = 'Voc deve adicionar SQL ao seu reporte.';	
	$lang['strreportcreated'] = 'Reporte salvo.';					
	$lang['strreportcreatedbad'] = 'Falha ao salvar o reporte.';		

	// Miscellaneous
	$lang['strtopbar'] = '%s rodando em %s:%s -- Voc est logado como usurio "%s", %s';
	$lang['strtimefmt'] = 'jS M, Y g:iA';

?>
